<?php

/**
 * OpenKM, Open Knowledge Management System S.L.  (http://www.openkm.com)
 * Copyright (c) 2006-2017
 *
 * No bytes were intentionally harmed during the development of this application.
 *
 * This program is commercial software; you can use it under the terms of the
 * EULA - OpenKM SDK End User License Agreement as published by OpenKM Knowledge Management System S.L.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * EULA - OpenKM SDK End User License Agreement for more details:
 * http://docs.openkm.com/kcenter/view/licenses/eula-openkm-sdk-end-user-license-agreement.html
 */

namespace openkm\impl;

use Httpful\Mime;
use Httpful\Request;
use openkm\bean\Document;
use openkm\bean\Folder;
use openkm\bean\LockInfo;
use openkm\bean\Version;
use openkm\bean\Note;
use openkm\bean\ContentInfo;

class ClientImpl {

    protected $host;
    protected $user;
    protected $password;

    /**
     * Construct
     */
    public function __construct($host, $user, $password) {
        $this->host = $host;
        $this->user = $user;
        $this->password = $password;
    }

    /**
     * getClient
     */
    public function getClient(Request $client) {
        $client->sends(Mime::XML);
        $client->expects(Mime::XML);
        $client->authenticateWith($this->user, $this->password);
        return $client->send();
    }

    /**
     * getClientWithUploadResponse
     */
    public function getClientWithUploadResponse(Request $client) {
        $client->sends(Mime::XML);
        $client->expects(Mime::UPLOAD);
        $client->authenticateWith($this->user, $this->password);
        return $client->send();
    }

    /**
     * getClientWithHTMLResponse
     */
    public function getClientWithHTMLResponse(Request $client) {
        $client->sends(Mime::XML);
        $client->expects(Mime::HTML);
        $client->authenticateWith($this->user, $this->password);
        return $client->send();
    }

    /**
     * getClientWithPlainResponse     
     */
    public function getClientWithPlainResponse(Request $client) {
        $client->sends(Mime::XML);
        $client->expects(Mime::PLAIN);
        $client->authenticateWith($this->user, $this->password);
        return $client->send();
    }

    public function phpDocument($documentXML) {
        $document = new Document();
        $document->setAuthor((string) $documentXML->author);
        $document->setCreated((string) $documentXML->created);        
        $document->setPath((string) $documentXML->path);
        $document->setPermissions((int) $documentXML->permissions);
        $document->setSubscribed((string) $documentXML->subscribed);
        $document->setUuid((string) $documentXML->uuid);

        //Version        
        $document->setActualVersion($this->phpVersion($documentXML->actualVersion));

        $document->setCheckedOut((string) $documentXML->checkedOut);
        $document->setConvertibleToDxf((string) $documentXML->convertibleToDxf);
        $document->setConvertibleToPdf((string) $documentXML->convertibleToPdf);
        $document->setConvertibleToSwf((string) $documentXML->convertibleToSwf);
        $document->setDescription((string) $documentXML->description);
        $document->setLanguage((string) $documentXML->language);
        $document->setLastModified((string) $documentXML->lastModified);

        //LockInfo        
        $document->setLockInfo($this->phpLockInfo($documentXML->lockInfo));

        $document->setLocked((string) $documentXML->locked);
        $document->setMimeType((string) $documentXML->mimeType);
        $document->setSigned((string) $documentXML->signed);
        $document->setTitle((string) $documentXML->title);

        //categories
        $categories = array();
        foreach ($documentXML->categories as $categoryXML) {
            $categories[] = $this->phpFolder($categoryXML);
        }
        $document->setCategories($categories);
        //keywords
        $keywords = array();
        foreach ($documentXML->keywords as $keywordXML) {
            $keywords[] = (string) $keywordXML;
        }
        $document->setKeywords($keywords);
        //notes
        $notes = array();
        foreach ($documentXML->notes as $noteXML) {
            $note = new Note();
            $note->setAuthor((string) $noteXML->author);
            $note->setDate((string) $noteXML->date);
            $note->setPath((string) $noteXML->path);
            $note->setText((string) $noteXML->text);
            $notes[] = $note;
        }
        $document->setNotes($notes);
        $subscriptors = array();
        foreach ($documentXML->subscriptors as $subscriptor) {
            $subscriptors[] = $subscriptor;
        }
        $document->setSubscriptors($subscriptors);
        return $document;
    }

    /**
     * Parse the XML a class
     * @param  \SimpleXMLElement $folderXML
     * @return \openkm\bean\Folder
     */
    public function phpFolderComplete($folderXML) {
        $folder = $this->phpFolder($folderXML);
        $categories = array();
        foreach ($folderXML->categories as $categoryXML) {
            $categories[] = $this->phpFolder($categoryXML);
        }
        $folder->setCategories($categories);
        $keywords = array();
        foreach ($folderXML->keywords as $keywordXML) {
            $keywords[] = (string) $keywordXML;
        }
        $folder->setKeywords($keywords);
        $notes = array();
        foreach ($folderXML->notes as $noteXML) {
            $note = new Note();
            $note->setAuthor((string) $noteXML->author);
            $note->setDate((string) $noteXML->date);
            $note->setPath((string) $noteXML->path);
            $note->setText((string) $noteXML->text);
            $notes[] = $note;
        }
        $folder->setNotes($notes);
        $subscriptors = array();
        foreach ($folderXML->subscriptors as $subscriptor) {
            $subscriptors[] = $subscriptor;
        }
        $folder->setSubscriptors($subscriptors);
        return $folder;
    }

    public function phpVersion($versionXML) {
        $version = new Version();
        $version->setActual((string) $versionXML->actual);
        $version->setAuthor((string) $versionXML->author);
        $version->setChecksum((string) $versionXML->checksum);
        $version->setCreated((string) $versionXML->created);
        $version->setName((string) $versionXML->name);
        $version->setSize((string) $versionXML->size);
        return $version;
    }

    public function phpLockInfo($lockInfoXML) {
        $lockInfo = new LockInfo();
        $lockInfo->setNodePath((string) $lockInfoXML->nodePath);
        $lockInfo->setOwner((string) $lockInfoXML->owner);
        $lockInfo->setToken((string) $lockInfoXML->token);
        return $lockInfo;
    }

    public function phpFolder($folderXML) {
        $folder = new Folder();
        $folder->setAuthor((string) $folderXML->author);
        $folder->setCreated((string) $folderXML->created);
        $folder->setPath((string) $folderXML->path);
        $folder->setPermissions((int) $folderXML->permissions);
        $folder->setSubscribed((string) $folderXML->subscribed);
        $folder->setUuid((string) $folderXML->uuid);
        $folder->setHasChildren((string) $folderXML->hasChildren);
        return $folder;
    }

    public function phpContentInfo($contentInfoXML) {
        $contentInfo = new ContentInfo();
        $contentInfo->setFolders((int) $contentInfoXML->folders);
        $contentInfo->setDocuments((int) $contentInfoXML->documents);
        $contentInfo->setMails((int) $contentInfoXML->mails);
        $contentInfo->setRecords((int) $contentInfoXML->records);
        $contentInfo->setSize((int) $contentInfoXML->size);
        return $contentInfo;
    }

}
